import { Commitment, Connection, RpcResponseAndContext, SimulatedTransactionResponse, Transaction, TransactionConfirmationStatus, TransactionSignature } from '@solana/web3.js';
import { BlockHeightStrategy, TimeStrategy, TransactionInstructionWithType, WalletSigner } from './types';
/**
 * waits for transaction confirmation
 * @param timeoutStrategy
 *
 *
 * TimeStrategy: pure timeout strategy
 * {
 *  timeout: optional, (secs) after how much secs not confirmed transaction will be considered timeout, default: 90
 *  getSignatureStatusesPoolIntervalMs: optional, (ms) pool interval of getSignatureStatues, default: 2000
 * }
 *
 *
 * BlockHeightStrategy: blockheight pool satrategy
 * {
 *  startBlockCheckAfterSecs: optional, (secs) after that time we will start to pool current blockheight and check if transaction will reach blockchain, default: 90
 *  block: BlockhashWithExpiryBlockHeight
 *  getSignatureStatusesPoolIntervalMs: optional, (ms) pool interval of getSignatureStatues and blockheight, default: 2000
 * }
 */
export declare const awaitTransactionSignatureConfirmation: ({ txid, confirmLevel, connection, timeoutStrategy, }: {
    txid: TransactionSignature;
    confirmLevel: TransactionConfirmationStatus;
    connection: Connection;
    timeoutStrategy: TimeStrategy | BlockHeightStrategy;
}) => Promise<unknown>;
/**
 * send and waits for transaction to confirm
 * @param postSendTxCallback call back that will fire after sending tx before waiting for tx to be confirmed.
 * @param timeoutStrategy
 *
 *
 * TimeStrategy: pure timeout strategy
 * {
 *  timeout: optional, (secs) after how much secs not confirmed transaction will be considered timeout, default: 90
 *  getSignatureStatusesPoolIntervalMs: optional, (ms) pool interval of getSignatureStatues, default: 2000
 * }
 *
 *
 * BlockHeightStrategy: blockheight pool satrategy
 * {
 *  startBlockCheckAfterSecs: optional, (secs) after that time we will start to pool current blockheight and check if transaction will reach blockchain, default: 90
 *  block: BlockhashWithExpiryBlockHeight
 *  getSignatureStatusesPoolIntervalMs: optional, (ms) pool interval of getSignatureStatues and blockheight, default: 2000
 * }
 */
export declare const sendAndConfirmSignedTransaction: ({ signedTransaction, confirmLevel, connection, postSendTxCallback, timeoutStrategy, }: {
    signedTransaction: Transaction;
    connection: Connection;
    confirmLevel?: TransactionConfirmationStatus | undefined;
    postSendTxCallback?: (({ txid }: {
        txid: string;
    }) => void) | undefined;
    timeoutStrategy: TimeStrategy | BlockHeightStrategy;
}) => Promise<string>;
/**
 * sign and send array of transactions in desired batches with different styles of send for each array
 * @param timeoutStrategy
 *
 * BlockHeightStrategy: blockheight pool satrategy
 * {
 *  startBlockCheckAfterSecs: optional, (secs) after that time we will start to pool current blockheight and check if transaction will reach blockchain, default: 90
 *  block: BlockhashWithExpiryBlockHeight
 *  getSignatureStatusesPoolIntervalMs: optional, (ms) pool interval of getSignatureStatues and blockheight, default: 2000
 * }
 */
export declare const sendSignAndConfirmTransactions: ({ connection, wallet, TransactionInstructions, timeoutStrategy, }: {
    connection: Connection;
    wallet: WalletSigner;
    TransactionInstructions: TransactionInstructionWithType[];
    timeoutStrategy: BlockHeightStrategy;
}) => Promise<void>;
/** Copy of Connection.simulateTransaction that takes a commitment parameter. */
export declare function simulateTransaction(connection: Connection, transaction: Transaction, commitment: Commitment): Promise<RpcResponseAndContext<SimulatedTransactionResponse>>;
